@@ -56,12 +56,7 @@ def handle_request(pattern, auth_required=True):
         if match is not None:
             mpd_commands.add(
                 MpdCommand(name=match.group(), auth_required=auth_required))
-        # NOTE Make pattern a bytestring to get bytestring keys in the dict
-        # returned from matches.groupdict(), which is again used as a **kwargs
-        # dict. This is needed to work on Python < 2.6.5.
-        # See https://github.com/mopidy/mopidy/issues/302 for details.
-        bytestring_pattern = pattern.encode('utf-8')
-        compiled_pattern = re.compile(bytestring_pattern, flags=re.UNICODE)
+        compiled_pattern = re.compile(pattern, flags=re.UNICODE)
         if compiled_pattern in request_handlers:
             raise ValueError('Tried to redefine handler for %s with %s' % (
                 pattern, func))
@@ -77,9 +72,7 @@ def load_protocol_modules():
     The protocol modules must be imported to get them registered in
     :attr:`request_handlers` and :attr:`mpd_commands`.
     """
-    # pylint: disable = W0612
     from . import (  # noqa
         audio_output, channels, command_list, connection, current_playlist,
         empty, music_db, playback, reflection, status, stickers,
         stored_playlists)
-    # pylint: enable = W0612
