@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 
+from mopidy.frontends.mpd.exceptions import MpdNoExistError
 from mopidy.frontends.mpd.protocol import handle_request
-from mopidy.frontends.mpd.exceptions import MpdNotImplemented
 
 
 @handle_request(r'^disableoutput "(?P<outputid>\d+)"$')
@@ -13,7 +13,10 @@ def disableoutput(context, outputid):
 
         Turns an output off.
     """
-    raise MpdNotImplemented  # TODO
+    if int(outputid) == 0:
+        context.core.playback.set_mute(False)
+    else:
+        raise MpdNoExistError('No such audio output', command='disableoutput')
 
 
 @handle_request(r'^enableoutput "(?P<outputid>\d+)"$')
@@ -25,7 +28,10 @@ def enableoutput(context, outputid):
 
         Turns an output on.
     """
-    raise MpdNotImplemented  # TODO
+    if int(outputid) == 0:
+        context.core.playback.set_mute(True)
+    else:
+        raise MpdNoExistError('No such audio output', command='enableoutput')
 
 
 @handle_request(r'^outputs$')
@@ -37,8 +43,9 @@ def outputs(context):
 
         Shows information about all outputs.
     """
+    muted = 1 if context.core.playback.get_mute().get() else 0
     return [
         ('outputid', 0),
-        ('outputname', 'Default'),
-        ('outputenabled', 1),
+        ('outputname', 'Mute'),
+        ('outputenabled', muted),
     ]
